@@ -7,6 +7,7 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
+	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/ssh"
 )
 
@@ -93,7 +94,7 @@ func init() {
 		},
 		ShowHostname: true,
 		Metadata: map[string]string{
-			"OSType": osTypeLinux,
+			metadataOSType: osTypeLinux,
 		},
 	}
 
@@ -103,6 +104,7 @@ func init() {
 				AbstractExecutor: executors.AbstractExecutor{
 					ExecutorOptions: options,
 				},
+				volumeParser: parser.NewLinuxParser(),
 			},
 		}
 		e.SetCurrentStage(common.ExecutorStageCreated)
