@@ -1782,163 +1782,6 @@ func TestCheckOSType(t *testing.T) {
 	}
 }
 
-// TODO: Remove in 12.0
-func TestOutdatedHelperImage(t *testing.T) {
-	ffNotSet := common.JobVariables{}
-	ffSet := common.JobVariables{
-		{Key: featureflags.DockerHelperImageV2, Value: "true"},
-	}
-
-	testCases := map[string]struct {
-		helperImage    string
-		variables      common.JobVariables
-		expectedResult bool
-	}{
-		"helper image not set and FF set to false": {
-			variables:      ffNotSet,
-			helperImage:    "",
-			expectedResult: false,
-		},
-		"helper image not set and FF set to true": {
-			variables:      ffSet,
-			helperImage:    "",
-			expectedResult: false,
-		},
-		"helper image set and FF set to false": {
-			variables:      ffNotSet,
-			helperImage:    "gitlab/gitlab-runner-helper:x86_64-latest",
-			expectedResult: true,
-		},
-		"helper image set and FF set to true": {
-			variables:      ffSet,
-			helperImage:    "gitlab/gitlab-runner-helper:x86_64-latest",
-			expectedResult: false,
-		},
-	}
-
-	for testName, testCase := range testCases {
-		t.Run(testName, func(t *testing.T) {
-			e := setUpExecutorForFeatureFlag(testCase.variables, testCase.helperImage, nil)
-			assert.Equal(t, testCase.expectedResult, e.checkOutdatedHelperImage())
-		})
-	}
-}
-
-// TODO: Remove in 12.0
-func TestRunServiceHealthCheckContainerFeatureFlag(t *testing.T) {
-	var cases = []struct {
-		name        string
-		variables   common.JobVariables
-		helperImage string
-		expectedCmd []string
-	}{
-		{
-			name:        "Helper image is not specified",
-			variables:   common.JobVariables{},
-			helperImage: "",
-			expectedCmd: []string{"gitlab-runner-helper", "health-check"},
-		},
-		{
-			name: "Helper image is not specified and FF still turned on",
-			variables: common.JobVariables{
-				common.JobVariable{Key: featureflags.DockerHelperImageV2, Value: "true"},
-			},
-			helperImage: "",
-			expectedCmd: []string{"gitlab-runner-helper", "health-check"},
-		},
-		{
-			name:        "Helper image is specified",
-			variables:   common.JobVariables{},
-			helperImage: "gitlab/gitlab-runner-helper:x86_64-latest",
-			expectedCmd: []string{"gitlab-runner-service"},
-		},
-		{
-			name: "Helper image is specified & FF variable is set to true",
-			variables: common.JobVariables{
-				common.JobVariable{Key: featureflags.DockerHelperImageV2, Value: "true"},
-			},
-			helperImage: "gitlab/gitlab-runner-helper:x86_64-latest",
-			expectedCmd: []string{"gitlab-runner-helper", "health-check"},
-		},
-	}
-
-	for _, testCase := range cases {
-		t.Run(testCase.name, func(t *testing.T) {
-			helperImageID := fmt.Sprintf("%s-helperImage-%d", t.Name(), time.Now().Unix())
-			containerID := fmt.Sprintf("%s-%d", t.Name(), time.Now().Unix())
-			serviceContainerID := fmt.Sprintf("%s-wait-for-service", containerID)
-
-			mClient := docker_helpers.MockClient{}
-			defer mClient.AssertExpectations(t)
-			mClient.On("ImageInspectWithRaw", mock.Anything, mock.Anything).
-				Return(types.ImageInspect{ID: helperImageID}, nil, nil)
-			mClient.On("ContainerStart", mock.Anything, serviceContainerID, mock.Anything).Return(nil).Once()
-			mClient.On("ContainerInspect", mock.Anything, serviceContainerID).Return(types.ContainerJSON{
-				ContainerJSONBase: &types.ContainerJSONBase{
-					State: &types.ContainerState{
-						ExitCode: 0,
-					},
-				},
-			}, nil).Once()
-			mClient.On("NetworkList", mock.Anything, mock.Anything).Return([]types.NetworkResource{}, nil).Once()
-			mClient.On("ContainerRemove", mock.Anything, serviceContainerID, mock.Anything).Return(nil).Once()
-			if testCase.helperImage != "" {
-				mClient.On("ImagePullBlocking", mock.Anything, mock.Anything, mock.Anything).Return(nil).Maybe()
-			}
-
-			executor := setUpExecutorForFeatureFlag(testCase.variables, testCase.helperImage, &mClient)
-
-			service := &types.Container{
-				ID:    containerID,
-				Names: []string{containerID},
-			}
-
-			expectedConfig := &container.Config{
-				Cmd:    testCase.expectedCmd,
-				Image:  helperImageID,
-				Labels: executor.getLabels("wait", "wait="+service.ID),
-			}
-
-			mClient.On("ContainerCreate", mock.Anything, expectedConfig, mock.Anything, mock.Anything, serviceContainerID).
-				Return(container.ContainerCreateCreatedBody{ID: serviceContainerID}, nil).
-				Once()
-
-			err := executor.runServiceHealthCheckContainer(service, time.Minute)
-			assert.NoError(t, err)
-		})
-	}
-}
-
-// TODO: Remove in 12.0
-func setUpExecutorForFeatureFlag(variables common.JobVariables, helperImage string, client docker_helpers.Client) executor {
-	return executor{
-		AbstractExecutor: executors.AbstractExecutor{
-			Config: common.RunnerConfig{
-				RunnerSettings: common.RunnerSettings{
-					Docker: &common.DockerConfig{
-						HelperImage: helperImage,
-					},
-				},
-			},
-			Build: &common.Build{
-				JobResponse: common.JobResponse{
-					Variables: variables,
-				},
-				Runner: &common.RunnerConfig{
-					RunnerCredentials: common.RunnerCredentials{
-						Token: "xxxxx",
-					},
-				},
-			},
-			Context: context.Background(),
-		},
-		client: client,
-		info: types.Info{
-			OSType: helperimage.OSTypeLinux,
-		},
-	}
-}
-
 func init() {
 	docker_helpers.HomeDirectory = ""
 }
